package com.sooka.sponest.middleware.base.controller;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.constant.HttpStatus;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.datascope.base.domain.BaseBusinessEntity;
import com.sooka.sponest.middleware.base.entity.bo.BaseESBO;
import com.sooka.sponest.middleware.base.entity.vo.CameraVO;
import com.sooka.sponest.middleware.base.service.IBaseESService;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.common.geo.GeoDistance;
import org.elasticsearch.common.geo.GeoPoint;
import org.elasticsearch.common.unit.DistanceUnit;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.elasticsearch.search.sort.SortBuilder;
import org.elasticsearch.search.sort.SortBuilders;
import org.elasticsearch.search.sort.SortOrder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class BaseESController {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBaseESService baseESService;

    static final String LOCATION = "location";

    public void dataPower(BoolQueryBuilder queryBuilder, String field, Long deptId) {
        List<Long> deptIds = null;
        if (StringUtils.isNotNull(deptId)) {
            deptIds = baseESService.getDeptAndChildIds(deptId);
        } else {
            deptIds = baseESService.getDeptIds(new BaseBusinessEntity());
        }
        if (StringUtils.isNotEmpty(deptIds)) {
            BoolQueryBuilder queryBuilderOr = QueryBuilders.boolQuery();
            deptIds.forEach(item -> queryBuilderOr.should().add(QueryBuilders.termQuery(field, item)));
            queryBuilder.must(queryBuilderOr);
        }
    }

    public List<CameraVO> getCameraList(List<JSONObject> pointList) {
        return baseESService.getCameraList(pointList);
    }

    public List<String> getPictureList(String busId) {
        return baseESService.getPictureList(busId);
    }

    @Autowired
    private RestHighLevelClient restHighLevelClient;

    /**
     * ES全文搜索
     *
     * @param esbo
     * @param sourceBuilder
     * @return
     */
    public SearchResponse getResponse(BaseESBO esbo, SearchSourceBuilder sourceBuilder) {
        sourceBuilder.trackTotalHits(true);// 返回所有命中，默认返回10000条
        // 分页查询
        if (StringUtils.isNotNull(esbo.getPageNum()) && StringUtils.isNotNull(esbo.getPageSize())) {
            sourceBuilder.from((esbo.getPageNum() - 1) * esbo.getPageSize()).size(esbo.getPageSize());
        }
        // 排序，默认按创建时间降序
        SortBuilder sortBuilder = null;
        if (StringUtils.isBlank(esbo.getSortFiled())) {
            sortBuilder = SortBuilders.fieldSort("createTime").order(SortOrder.DESC);
        } else if (LOCATION.equals(esbo.getSortFiled())) {
            // 按照距离排序
            sortBuilder = SortBuilders.geoDistanceSort(LOCATION,
                    new GeoPoint(Double.parseDouble(esbo.getLatitude()), Double.parseDouble(esbo.getLongitude())))
                    .order(esbo.getSortOrder()).unit(DistanceUnit.METERS).geoDistance(GeoDistance.PLANE);
        } else {
            sortBuilder = SortBuilders.fieldSort(esbo.getSortFiled()).order(esbo.getSortOrder());
        }
        sourceBuilder.sort(sortBuilder);
        // 包含、不包含
        if (StringUtils.isNotEmpty(esbo.getIncludeFields()) || StringUtils.isNotEmpty(esbo.getExcludeFields())) {
            sourceBuilder.fetchSource(esbo.getIncludeFields(), esbo.getExcludeFields());
        }
        // 根据索引名创建搜索请求
        SearchRequest request = new SearchRequest(esbo.getIndexNames());
        request.source(sourceBuilder);// 将构建查询放进请求中
        SearchResponse response = null;
        try {
            // 获取请求的响应数据
            response = restHighLevelClient.search(request, RequestOptions.DEFAULT);
            logger.info("花费的时长：{}", response.getTook());
        } catch (IOException e) {
            logger.error(e.getMessage());
        }
        return response;
    }

    public List<JSONObject> getDataList(BaseESBO esbo, SearchResponse response) {
        if (StringUtils.isNull(response)) {
            return new ArrayList<>();
        }
        // 解析响应
        SearchHit[] searchHits = response.getHits().getHits();// 获取命中
        List<JSONObject> resultList = new ArrayList<>();
        for (SearchHit hit : searchHits) {
            String json = hit.getSourceAsString();// 获取文档source
            JSONObject jsonObject = JSONObject.parseObject(json);// 反序列化
            jsonObject.put("indexName", hit.getIndex());
            if (LOCATION.equals(esbo.getSortFiled())) {
                BigDecimal geoDis = new BigDecimal(hit.getSortValues()[0].toString());
                jsonObject.put("distance", geoDis.setScale(0, BigDecimal.ROUND_HALF_DOWN));
            }
            resultList.add(jsonObject);
        }
        return resultList;
    }

    public TableDataInfo getDataTable(BaseESBO esbo, SearchResponse response) {
        if (StringUtils.isNull(response)) {
            return new TableDataInfo();
        }
        TableDataInfo rspData = new TableDataInfo();
        rspData.setTotal(response.getHits().getTotalHits().value);
        rspData.setRows(getDataList(esbo, response));
        rspData.setCode(HttpStatus.SUCCESS);
        rspData.setMsg("查询成功");
        return rspData;
    }
}
