package com.sooka.sponest.middleware.event.consumer;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.redis.service.RedisService;
import com.sooka.sponest.middleware.base.config.ParamConfig;
import com.sooka.sponest.middleware.event.eventcatalogue.entity.EventCatalogue;
import com.sooka.sponest.middleware.event.eventcatalogue.entity.EventLog;
import com.sooka.sponest.middleware.event.eventcatalogue.entity.bo.EventBO;
import com.sooka.sponest.middleware.event.eventcatalogue.service.IEventCatalogueService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.stream.annotation.EnableBinding;
import org.springframework.cloud.stream.annotation.StreamListener;
import org.springframework.cloud.stream.messaging.Sink;
import org.springframework.messaging.Message;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@EnableBinding({Sink.class, EventSink.class}) // （Sink也是spring的）
public class EventListener {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IEventCatalogueService eventCatalogueService;

    // 监听
    @StreamListener(EventSink.EVENT_PUSH)
    public void input(Message<EventBO> message) {
        EventBO eventBo = message.getPayload();
        logger.info("---消费者---{}", eventBo);
        if (StringUtils.isBlank(eventBo.getEventCode())) {
            return;
        }
        if (BusinessType.DELETE.equals(eventBo.getBusinessType())) {
            // 删除
            eventCatalogueService.deleteEventCatalogueByEventCode(eventBo.getEventCode());
        } else {
            Map<String, Object> params = new HashMap<>();
            params.put("databaseSystem", ParamConfig.getSystemDB());
            params.put("eventCode", eventBo.getEventCode());
            List<EventCatalogue> eventCatalogues = eventCatalogueService.getEventCatalogues(params);
            if (StringUtils.isNotEmpty(eventCatalogues)) {
                eventCatalogueService.saveAll(eventCatalogues);
            }
        }
    }

    @StreamListener(EventSink.URGE_PUSH)
    public void input1(Message<String> message) {
        String eventCode = message.getPayload();
        logger.info("---待催办---{}", eventCode);
        Map<String, Object> params = new HashMap<>();
        params.put("databaseSystem", ParamConfig.getSystemDB());
        params.put("eventCode", eventCode);
        List<EventCatalogue> eventCatalogues = eventCatalogueService.getEventCatalogues(params);
        eventCatalogues.stream().filter(catalogue -> "sys_isurge_2".equals(catalogue.getIsUrged()) && "forest_event_status_1".equals(catalogue.getEventStatusValue()))
                .findFirst().ifPresent(catalogue -> {
            RedisService redisService = SpringUtils.getBean(RedisService.class);
            String key = "event:urge:" + eventCode;
            // 判断当前事件在redis是否存在，存在则删除
            if (redisService.hasKey(key)) {
                redisService.deleteObject(key);
            }
            logger.info("---开始催办---{}", eventCode);
            // 更新催办状态
            int result = eventCatalogueService.updateCentereventTEventcatalogue(eventCode);
            if (result > 0) {
                eventCatalogueService.saveAll(eventCatalogues);// 同步es
            }
            // 加个日志
            EventLog eventLog = new EventLog();
            eventLog.setId(IdUtils.simpleUUID());
            eventLog.setEventCode(eventCode);
            eventLog.setLogContent("你的这个事件被催办了！赶快处理了");
            eventLog.setCreateName("系统");
            eventLog.setCreateTime(DateUtils.getNowDate());
            eventCatalogueService.insertCentereventTFireLog(eventLog);
        });
    }
}
