package com.sooka.sponest.middleware.event.eventcatalogue.controller;

import com.ruoyi.common.core.utils.SpringUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.redis.service.RedisService;
import com.sooka.sponest.middleware.base.config.ParamConfig;
import com.sooka.sponest.middleware.event.eventcatalogue.entity.EventCatalogue;
import com.sooka.sponest.middleware.event.eventcatalogue.service.IEventCatalogueService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author lyq
 * @date 2023年7月24日
 */
@Configuration
@EnableScheduling
public class ESScheduleTask {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IEventCatalogueService eventCatalogueService;

    static final String TESTMQ_LOCK = "testmq:lock";

    /**
     * 定时任务 同步昨日事件数据
     */
    @Scheduled(cron = "0 0 1 * * ?")
    private void demo() {
        // 读取缓存
        RedisService redis = SpringUtils.getBean(RedisService.class);
        String lock = redis.getCacheObject(TESTMQ_LOCK);
        if (StringUtils.isBlank(lock)) {
            redis.setCacheObject(TESTMQ_LOCK, "随便放点啥");
            long total = 0;
            long num = 1;// pageNum
            long size = 200;// pageSize
            long start = (num - 1) * size;
            Map<String, Object> params = new HashMap<>();
            params.put("databaseSystem", ParamConfig.getSystemDB());
            // 默认同步昨日数据 DATEDIFF(now(), create_time/update_time) = 1
            params.put("dateDiff", "1");
            params.put("start", start);
            params.put("size", size);
            List<EventCatalogue> eventCatalogues = eventCatalogueService.getEventCatalogues(params);
            while (StringUtils.isNotEmpty(eventCatalogues)) {
                eventCatalogueService.saveAll(eventCatalogues);
                total += eventCatalogues.size();
                logger.info("---处理中---{}", total);
                num++;
                start = (num - 1) * size;
                params.put("start", start);
                eventCatalogues = eventCatalogueService.getEventCatalogues(params);
            }
            redis.setCacheObject(TESTMQ_LOCK, total, (long) 3600 * 12, TimeUnit.SECONDS);
        }
        logger.info("---处理完成---");
    }
}
