package com.sooka.sponest.middleware.event.eventcatalogue.controller;

import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.sooka.sponest.middleware.base.config.ParamConfig;
import com.sooka.sponest.middleware.base.controller.BaseESController;
import com.sooka.sponest.middleware.event.eventcatalogue.entity.EventCatalogue;
import com.sooka.sponest.middleware.event.eventcatalogue.entity.bo.EventCatalogueBO;
import com.sooka.sponest.middleware.event.eventcatalogue.service.IEventCatalogueService;
import org.apache.commons.collections4.MapUtils;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @Auther: mjq
 * @Date: 2023/7/5 - 07 - 05 - 22:57
 * @Description: com.sooka.sponest.rabbitmq.event.es
 * @version: 1.0
 */
@RestController
@RequestMapping("/eventcatalogue")
public class EventCatalogueController extends BaseESController {

    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IEventCatalogueService cnterEventService;

    static final String EVENT_STATUS_VALUE = "eventStatusValue.keyword";

    /**
     * 批处理
     *
     * @param params
     */
    @PostMapping("/saveEventBatch")
    public void saveEventBatch(@RequestBody Map<String, Object> params) {
        params.put("databaseSystem", ParamConfig.getSystemDB());
        long total = MapUtils.getLong(params, "total");// 要处理的总数
        long num = MapUtils.getLong(params, "num");
        long size = MapUtils.getLong(params, "size");
        long start = (num - 1) * size;
        logger.info("---批处理开始---需处理：{}", total);
        List<EventCatalogue> eventCatalogues = null;
        while (total > 0) {
            params.put("start", start);
            eventCatalogues = cnterEventService.getEventCatalogues(params);
            if (StringUtils.isEmpty(eventCatalogues)) {
                break;
            }
            cnterEventService.saveAll(eventCatalogues);
            total -= eventCatalogues.size();
            logger.info("---处理中---剩余{}", total);
            num++;
            start = (num - 1) * size;
        }
        logger.info("---批处理完成---{}", total);
    }

    /**
     * 查询ES事件列表的接口
     *
     * @return
     * @throws Exception
     */
    @PostMapping("/listsearcheventlogue")
    public TableDataInfo listsearcheventlogue(@RequestBody EventCatalogueBO bo) {
        BoolQueryBuilder queryBuilder = QueryBuilders.boolQuery();
        // 事件名称
        if (StringUtils.isNotBlank(bo.getEventName())) {
            queryBuilder.must(QueryBuilders.wildcardQuery("eventName.keyword", new StringBuilder().append("*").append(bo.getEventName()).append("*").toString()));
        }
        // 事件来源
        if (StringUtils.isNotBlank(bo.getReportSource())) {
            queryBuilder.must(QueryBuilders.termQuery("reportSource.keyword", bo.getReportSource()));
        }
        // 上报人
        if (StringUtils.isNotBlank(bo.getReportor())) {
            queryBuilder.must(QueryBuilders.wildcardQuery("reportor.keyword", new StringBuilder().append("*").append(bo.getReportor()).append("*").toString()));
        }
        // 上报时间
        if (StringUtils.isNotEmpty(bo.getReportTimeRange())) {
            queryBuilder.must(QueryBuilders.rangeQuery("createTime").gte(bo.getReportTimeRange().get(0)).lte(bo.getReportTimeRange().get(1)));
        }
        // 是否催办
        if (StringUtils.isNotBlank(bo.getIsUrged())) {
            queryBuilder.must(QueryBuilders.termQuery("isUrged.keyword", bo.getIsUrged()));
        }
        // 事件状态
        if (StringUtils.isNotBlank(bo.getEventStatusValue())) {
            queryBuilder.must(QueryBuilders.termQuery(EVENT_STATUS_VALUE, bo.getEventStatusValue()));
        }
        // 事件类型
        BoolQueryBuilder queryBuilderOr = QueryBuilders.boolQuery();
        if (StringUtils.isEmpty(bo.getEventTypeXls())) {
            bo.getDefaultTypeXl().forEach(item -> queryBuilderOr.should().add(QueryBuilders.termQuery("eventTypeXl.keyword", item)));
            if (bo.getDefaultTypeXl().contains("1")) {
                BoolQueryBuilder builder = QueryBuilders.boolQuery();
                builder.must(QueryBuilders.termQuery("eventType.keyword", "1"));
                BoolQueryBuilder builderOr = QueryBuilders.boolQuery();
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_1"));
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_7"));
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_3"));
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_4"));
                builder.must(builderOr);
                queryBuilderOr.should().add(builder);
            }
        } else {
            bo.getEventTypeXls().forEach(item -> queryBuilderOr.should().add(QueryBuilders.termQuery("eventTypeXl.keyword", item)));
            if (bo.getEventTypeXls().contains("1")) {
                BoolQueryBuilder builder = QueryBuilders.boolQuery();
                builder.must(QueryBuilders.termQuery("eventType.keyword", "1"));
                BoolQueryBuilder builderOr = QueryBuilders.boolQuery();
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_1"));
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_7"));
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_3"));
                builderOr.should().add(QueryBuilders.termQuery(EVENT_STATUS_VALUE, "forest_event_status_4"));
                builder.must(builderOr);
                queryBuilderOr.should().add(builder);
            }
        }
        queryBuilder.must(queryBuilderOr);
        // 数据权限
        dataPower(queryBuilder, "deptIds", null);
        // 指定查询索引
        bo.setIndexNames(new String[]{"event_catalogue"});
        // 创建搜索资源构建对象
        SearchSourceBuilder sourceBuilder = new SearchSourceBuilder();
        sourceBuilder.query(queryBuilder);// 创建全文搜索
        SearchResponse response = getResponse(bo, sourceBuilder);
        return getDataTable(bo, response);
    }
}
