package com.sooka.sponest.middleware.event.producer.impl;

import com.sooka.sponest.middleware.event.producer.MsgEventService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.connection.CorrelationData;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Service;

import java.nio.charset.StandardCharsets;
import java.util.UUID;

/**
 * @Auther: mjq
 * @Date: 2023/7/5 - 07 - 05 - 13:26
 * @Description: com.sooka.sponest.middleware.event.producer.Impl
 * @version: 1.0
 */
@Slf4j
@Service
public class MsgEventServiceImpl implements MsgEventService {

    @Autowired
    private RabbitTemplate rabbitTemplate;

    /**
     * 发送普通消息到消费队列
     *
     * @param msg
     */
    public void sendMsg(String exchange, String routeKey, String msg) {
        // 1.准备消息
        // MessageDeliveryMode.PERSISTENT 消息持久化，这样重启mq消息也可以保留
        Message message = MessageBuilder.withBody(msg.getBytes(StandardCharsets.UTF_8))
                .setDeliveryMode(MessageDeliveryMode.PERSISTENT).build();
        // 2.准备CorrelationData
        // 2.1.消息ID
        CorrelationData correlationData = new CorrelationData(UUID.randomUUID().toString());
        // 2.2.准备ConfirmCallback
        correlationData.getFuture().addCallback(result -> {   //成功回调
            // 判断结果
            if (result.isAck()) {
                log.debug("消息成功投递到交换机！消息ID：{}", correlationData.getId());// ACK
            } else {
                log.error("消息投递到交换机失败！消息ID：{}", correlationData.getId());// NACK
                // 重发消息
            }
        }, ex -> log.error("消息发送失败！", ex));// 失败回调,记录日志
        // 3.发送消息
        rabbitTemplate.convertAndSend(exchange, routeKey, message);
    }

    // 交换机持久化
    @Bean
    public DirectExchange simpleDirect() {
        // 三个参数：交换机名称、是否持久化、当没有queue与其绑定时是否自动删除
        return new DirectExchange("simple.direct", true, false);
    }

    // 队列持久化
    @Bean
    public Queue simpleQueue() {
        // 使用QueueBuilder构建队列，durable就是持久化的   nonDurable()非持久化的
        return QueueBuilder.durable("simple.queue").build();
    }
}
